@@ -197,6 +197,7 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
   //delta = (MYREAL *) mycalloc(nn-1, sizeof(MYREAL));
   n = (long *) mycalloc(numpop2 + world->bayes->mu * world->loci, sizeof(long));
   input = (char *) mycalloc(SUPERLINESIZE, sizeof(char));
+  printf("Begin reading the bayesallfile back into the system\n");
 #ifdef ZNZ
   unsigned long bytes = SUPERLINESIZE > ONEMEGABYTE ? SUPERLINESIZE : ONEMEGABYTE;
   znzbuffer(mdimfile,bytes);
@@ -205,6 +206,7 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
   while(FGETS(input,SUPERLINESIZE,mdimfile) != EOF)
 #endif
     {
+      printf("%s\n",input);
       // grab the commentlines
       while(input[0]=='#' || input[0]=='S')
 	{
@@ -212,14 +214,16 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
 	  ZNZFGETS(input,SUPERLINESIZE,mdimfile);
 #else
 	  FGETS(input,SUPERLINESIZE,mdimfile);
+	  printf("#### %s\n",input);
 #endif
 	}
       // read the bayesallfile
-      
+       printf("%s\n",input);
       if(input !=NULL)
 	{
 	  inptr = input;
 	  step       = atol(strsep(&inptr,"\t"));
+	  printf("%li\n",step);
 	  locus      = atol(strsep(&inptr,"\t"))-1;
 	  if(locus == -1)
 	    error("help");
@@ -321,6 +325,7 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
 #endif
 	}
     }
+  printf("End reading the bayesallfile back into the system\n");
 #ifdef BFDEBUG
   if(world->options->datatype == 'g')
     {
@@ -342,6 +347,7 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
 	}
     }
 #endif /*BFDEBUG*/
+
   myfree(params);
   myfree(autocorrelation);
   myfree(lowerbound);
