@@ -24,7 +24,7 @@ Copyright 2003-2005 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: laguerre.c 1800 2011-01-29 13:40:00Z beerli $
+$Id: laguerre.c 1891 2011-05-26 16:45:51Z beerli $
 */
 /* \file laguerre.c
 Calculates the Laguerre Quadrature points, used for gamma deviated site rate variation
@@ -483,7 +483,7 @@ main ()
     MYREAL *probcat;
     long i;
     printf ("Enter alpha, theta1,  and categs\n");
-    fscanf (stdin, "%lf%lf%li", &alpha, &theta1, &categs);
+    retval = fscanf (stdin, "%lf%lf%li", &alpha, &theta1, &categs);
     rate = (MYREAL *) mycalloc (categs + 1, sizeof (MYREAL));
     probcat = (MYREAL *) mycalloc (categs + 1, sizeof (MYREAL));
     initgammacat (categs, alpha, theta1, rate, probcat);
