@@ -16,7 +16,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: lrt.c 1701 2010-06-13 21:00:45Z beerli $
+$Id: lrt.c 1800 2011-01-29 13:40:00Z beerli $
  
 -------------------------------------------------------*/
 /* \file lrt.c 
@@ -170,7 +170,7 @@ test_loci_like (nr_fmt * nr, MYREAL *param0, MYREAL *param1, long df,
     //long zi;
     long z = 0, w = 0;
     // long pop;
-    MYREAL normd = 0.0;
+    //MYREAL normd = 0.0;
     long *which;
     MYREAL **hess;
     MYREAL /**values,*/ *saveparam0;
@@ -221,7 +221,7 @@ test_loci_like (nr_fmt * nr, MYREAL *param0, MYREAL *param1, long df,
         nr->profilenum = w;
         maximize (&param0, world, nr, hess, PROFILE, world->repkind);
         like0 = nr->llike;
-        normd = nr->normd;
+        //xcode normd = nr->normd;
         memcpy (param0, world->param0, sizeof (MYREAL) * nr->partsize);
     }
     else
@@ -347,7 +347,7 @@ void parse_h0part(char ***box, long *size, long *tempsize,
     MYREAL tparam;
     char tmp[LRATIO_STRINGS];
     long counter = 0;
-    length = (int) MAX (0, 5 - sprintf (tmp, "%i", ((int) param[0])));
+   //xcode  length = (int) MAX (0, 5 - sprintf (tmp, "%i", ((int) param[0])));
     counter = sprintf ((*box)[*tempsize],"%3.3s", head);
     for (i = 0; i < elem; i++)
       {
@@ -446,7 +446,7 @@ set_test_param (MYREAL *param, lr_data_fmt *lrtdata, world_fmt * world, long lrl
     char *ss;
     char **custm;
     MYREAL *meanparam;
-    long zzz;
+    //long zzz;
     long zi;
     long el;
     long df = 0;
@@ -470,7 +470,7 @@ set_test_param (MYREAL *param, lr_data_fmt *lrtdata, world_fmt * world, long lrl
     if(elem != elements)
         warning("Not enough elements in the l-ratio specification\n");
 
-    zzz=0;
+   //xcode  zzz=0;
     if (world->loci - world->skipped > 1)
         meanparam = world->atl[0][world->loci].param;
     else
