@@ -26,7 +26,7 @@
 *   works and am not responsible for any damage you may cause or have.
 *
 */
-/* $Id: main.c 1924 2011-06-09 22:02:51Z beerli $*/
+/* $Id: main.c 1961 2011-10-07 02:10:19Z beerli $*/
 
 #include "migration.h"
 #include "sighandler.h"
@@ -2037,7 +2037,7 @@ run_locus (world_fmt ** universe, int usize, option_fmt * options,
         {
 	  if(!options->has_bayesmdimfile)
 	    {
-	      adjust_bayes_bins(EARTH,locus);
+	      //adjust_bayes_bins(EARTH,locus);
 	      calculate_credibility_interval (EARTH, locus);
 	    }
 	}
