@@ -16,7 +16,7 @@
  
   Copyright 2002 Peter Beerli and Joseph Felsenstein, Seattle WA
   Copyright 2003 Peter Beerli, Tallahassee FL
-  $Id: migration.h 1863 2011-04-12 18:06:40Z michal $
+  $Id: migration.h 1941 2011-08-07 23:08:22Z beerli $
   *----------------------------------------------------------------
 */
 /**
@@ -65,7 +65,8 @@ typedef ratelike *phenotype;
 typedef MYREAL contribarr[MAXCATEGS]; //!< \todo conditional likelihoods should change to 1-D vector
 typedef short seqval[MAXCATEGS]; 
 
-typedef char allele_fmt[DEFAULT_ALLELENMLENGTH];
+typedef char allele_fmt[LINESIZE];
+//typedef char allele_fmt[DEFAULT_ALLELENMLENGTH];
 
 /// tipdate format
 typedef struct tipdate_fmt 
@@ -252,7 +253,7 @@ typedef struct _data
     MYREAL *geo;            //!< geographic distance data holder
     MYREAL *lgeo;           //!< log of geo
     MYREAL **ogeo;          //!< original of geo as read from the geofile
-    allele_fmt **allele;    //
+    char ***allele;    //
     long *maxalleles;       //!< maximal number of alleles in dataset
     boolean *skiploci;      //!< number of loci to skip -- loci with no data
     char **popnames;        //!< array of the population names
@@ -937,7 +938,7 @@ typedef struct _worldoption
     boolean fast_aic;
     MYREAL aicmod;
     FILE *aicfile;
-    char aictype[2];
+    char aictype[3];
     MYREAL lambda;
     FILE *mixfile;
 #ifdef UEP
