@@ -22,7 +22,7 @@
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-   $Id: sighandler.c 1737 2010-10-21 16:10:07Z beerli $                  
+   $Id: sighandler.c 1874 2011-05-16 18:46:26Z beerli $                  
    ----------------------------------------------------- */
 /*! \file sighandler.c */
 #include "sighandler.h"
@@ -57,7 +57,7 @@ signalhandling (long switcher)
         signal (SIGIOT, signalhandler);
         signal (SIGTRAP, signalhandler);
         signal (SIGBUS, signalhandler);
-              signal (SIGUSR1, signalhandler);
+	//              signal (SIGUSR1, signalhandler);
 #ifndef SYSTEM_V
 
         signal (SIGXCPU, signalhandler);
@@ -77,7 +77,7 @@ signalhandling (long switcher)
         signal (SIGIOT, SIG_DFL);
         signal (SIGTRAP, SIG_DFL);
         signal (SIGBUS, SIG_DFL);
-	      signal (SIGUSR1, SIG_DFL);
+	//	      signal (SIGUSR1, SIG_DFL);
 #ifndef SYSTEM_V
 
         signal (SIGXCPU, SIG_DFL);
@@ -173,14 +173,14 @@ signalhandler (int sig)
                  "              report this error to your system administrator, please.\n");
         exit (sig);
         break;
-    case SIGUSR1:
+	////    case SIGUSR1:
 #ifdef MPI
-        fprintf(stderr, "On node %i happened a USER (%i) SIGNAL\n", myID, sig);
-	MPI_Finalize();
+	  ////fprintf(stderr, "On node %i happened a USER (%i) SIGNAL\n", myID, sig);
+	  ////MPI_Finalize();
 	//	exit(sig);
 #endif
         //      warning ("\nUser signal received and ignored\n\n");
-        break;
+        ////break;
 
 #endif /**__MWERKS__*/
 #endif /**WIN32*/
@@ -243,7 +243,7 @@ signalhandler (int sig)
 #ifndef __MWERKS__
     signal (SIGIOT, signalhandler);
     signal (SIGTRAP, signalhandler);
-    signal (SIGUSR1, signalhandler);
+    //    signal (SIGUSR1, signalhandler);
     signal (SIGBUS, signalhandler);
 #ifndef SYSTEM_V
 
